==> apache-any23-2.2-src.zip: apache-any23-2.2-src/core/src/test/java/org/apache/any23/util/DiscoveryUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.any23.util;

import org.apache.any23.vocab.Vocabulary;
import org.junit.Assert;
import org.junit.Test;
import org.eclipse.rdf4j.model.Resource;

import java.io.IOException;
import java.util.List;

/**
 * Test case for {@link DiscoveryUtils}.
 *
 * @author Michele Mostarda (mostarda@fbk.eu)
 */
public class DiscoveryUtilsTest {

    /**
     * Test case for {@link DiscoveryUtils#getClassesInPackage(String, Class)} with detection in classes dir.
     *
     * @throws ClassNotFoundException
     * @throws IOException
     */
    @Test
    public void testGetClassesInPackage() throws ClassNotFoundException, IOException {
        final List<Class> classes = DiscoveryUtils.getClassesInPackage("org.apache.any23.vocab", Vocabulary.class);
        Assert.assertTrue( classes.size() >= 13 );
    }

    /**
     * Test case for {@link DiscoveryUtils#getClassesInPackage(String, Class)} with detection in JAR file.
     *
     * @throws ClassNotFoundException
     * @throws IOException
     */
    @Test
    public void testGetClassesInJAR() throws ClassNotFoundException, IOException {
        final List<Class> classes = DiscoveryUtils.getClassesInPackage("org.eclipse.rdf4j", Resource.class);
        Assert.assertTrue( classes.size() >= 2 );
    }

}

==> apache-any23-2.4-src.zip: apache-any23-2.4-src/core/src/test/java/org/apache/any23/util/DiscoveryUtilsTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.any23.util;

import org.apache.any23.vocab.Vocabulary;
import org.junit.Assert;
import org.junit.Test;
import org.eclipse.rdf4j.model.Resource;

import java.io.IOException;
import java.util.List;

/**
 * Test case for {@link DiscoveryUtils}.
 *
 * @author Michele Mostarda (mostarda@fbk.eu)
 */
public class DiscoveryUtilsTest {

    /**
     * Test case for {@link DiscoveryUtils#getClassesInPackage(String, Class)} with detection in classes dir.
     *
     * @throws ClassNotFoundException if there is an error location class in 'org.apache.any23.vocab' package
     * @throws IOException if there is an error in the input
     */
    @Test
    public void testGetClassesInPackage() throws ClassNotFoundException, IOException {
        final List<Class> classes = DiscoveryUtils.getClassesInPackage("org.apache.any23.vocab", Vocabulary.class);
        Assert.assertTrue( classes.size() >= 13 );
    }

    /**
     * Test case for {@link DiscoveryUtils#getClassesInPackage(String, Class)} with detection in JAR file.
     *
     * @throws ClassNotFoundException if there is an error location class in 'org.eclipse.rdf4j' package
     * @throws IOException if there is an error in the input
     */
    @Test
    public void testGetClassesInJAR() throws ClassNotFoundException, IOException {
        final List<Class> classes = DiscoveryUtils.getClassesInPackage("org.eclipse.rdf4j", Resource.class);
        Assert.assertTrue( classes.size() >= 2 );
    }

}
